@@ -1,14 +1,8 @@
--- phpMyAdmin SQL Dump
--- version 2.8.0.3
--- http://www.phpmyadmin.net
 -- 
--- Host: localhost
--- Generation Time: Jun 10, 2006 at 11:08 PM
--- Server version: 5.0.18
--- PHP Version: 5.1.3
--- 
--- Database: `smsd`
+-- Database for Gammu SMSD
 -- 
+-- In case you get errors about not supported charset, please
+-- replace utf8mb4 with utf8.
 
 -- --------------------------------------------------------
 
@@ -19,7 +13,7 @@
 CREATE TABLE `daemons` (
   `Start` text NOT NULL,
   `Info` text NOT NULL
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 -- 
 -- Dumping data for table `daemons`
@@ -34,13 +28,13 @@ CREATE TABLE `daemons` (
 
 CREATE TABLE `gammu` (
   `Version` integer NOT NULL default '0'
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 -- 
 -- Dumping data for table `gammu`
 -- 
 
-INSERT INTO `gammu` (`Version`) VALUES (14);
+INSERT INTO `gammu` (`Version`) VALUES (15);
 
 -- --------------------------------------------------------
 
@@ -62,7 +56,7 @@ CREATE TABLE `inbox` (
   `RecipientID` text NOT NULL,
   `Processed` enum('false','true') NOT NULL default 'false',
   PRIMARY KEY `ID` (`ID`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 AUTO_INCREMENT=1 ;
 
 -- 
 -- Dumping data for table `inbox`
@@ -94,8 +88,9 @@ CREATE TABLE `outbox` (
   `SendingTimeOut` timestamp NULL default '0000-00-00 00:00:00',
   `DeliveryReport` enum('default','yes','no') default 'default',
   `CreatorID` text NOT NULL,
+  `Retries` int(3) default 0,
   PRIMARY KEY `ID` (`ID`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 CREATE INDEX outbox_date ON outbox(SendingDateTime, SendingTimeOut);
 CREATE INDEX outbox_sender ON outbox(SenderID);
@@ -120,7 +115,7 @@ CREATE TABLE `outbox_multipart` (
   `ID` integer unsigned NOT NULL default '0',
   `SequencePosition` integer NOT NULL default '1',
   PRIMARY KEY (`ID`, `SequencePosition`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 -- 
 -- Dumping data for table `outbox_multipart`
@@ -139,7 +134,7 @@ CREATE TABLE `pbk` (
   `Name` text NOT NULL,
   `Number` text NOT NULL,
   PRIMARY KEY (`ID`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 -- 
 -- Dumping data for table `pbk`
@@ -156,7 +151,7 @@ CREATE TABLE `pbk_groups` (
   `Name` text NOT NULL,
   `ID` integer NOT NULL auto_increment,
   PRIMARY KEY `ID` (`ID`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 AUTO_INCREMENT=1 ;
 
 -- 
 -- Dumping data for table `pbk_groups`
@@ -185,7 +180,7 @@ CREATE TABLE `phones` (
   `Sent` int NOT NULL DEFAULT 0,
   `Received` int NOT NULL DEFAULT 0,
   PRIMARY KEY (`IMEI`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 -- 
 -- Dumping data for table `phones`
@@ -218,7 +213,7 @@ CREATE TABLE `sentitems` (
   `RelativeValidity` integer NOT NULL default '-1',
   `CreatorID` text NOT NULL,
   PRIMARY KEY (`ID`, `SequencePosition`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4;
 
 CREATE INDEX sentitems_date ON sentitems(DeliveryDateTime);
 CREATE INDEX sentitems_tpmr ON sentitems(TPMR);
