@@ -712,6 +712,9 @@ void PrintToDo(GSM_ToDoEntry * ToDo)
 	PrintNoteType(ToDo->Type);
 	printf(LISTFORMAT, _("Priority"));
 	switch (ToDo->Priority) {
+		case GSM_Priority_INVALID:
+			printf("%s\n", _("Invalid"));
+			break;
 		case GSM_Priority_Low:
 			printf("%s\n", _("Low"));
 			break;
