@@ -294,6 +294,19 @@ GSM_Error GSM_SetLocale(GSM_StateMachine *s, GSM_Locale *locale)
 	PRINT_LOG_ERROR(err);
 	return err;
 }
+/**
+ * Power on/off the phone.
+ */
+GSM_Error GSM_SetPower(GSM_StateMachine *s, gboolean on)
+{
+	GSM_Error err;
+
+	CHECK_PHONE_CONNECTION();
+
+	err = s->Phone.Functions->SetPower(s, on);
+	PRINT_LOG_ERROR(err);
+	return err;
+}
 /**
  * Emulates key press or key release.
  */
@@ -952,20 +965,20 @@ GSM_Error GSM_SwitchCall(GSM_StateMachine *s, int ID, gboolean next)
 /**
  * Gets call diverts.
  */
-GSM_Error GSM_GetCallDivert(GSM_StateMachine *s, GSM_MultiCallDivert *divert)
+GSM_Error GSM_GetCallDivert(GSM_StateMachine *s, GSM_CallDivert *request, GSM_MultiCallDivert *result)
 {
 	GSM_Error err;
 
 	CHECK_PHONE_CONNECTION();
 
-	err = s->Phone.Functions->GetCallDivert(s, divert);
+	err = s->Phone.Functions->GetCallDivert(s, request, result);
 	PRINT_LOG_ERROR(err);
 	return err;
 }
 /**
  * Sets call diverts.
  */
-GSM_Error GSM_SetCallDivert(GSM_StateMachine *s, GSM_MultiCallDivert *divert)
+GSM_Error GSM_SetCallDivert(GSM_StateMachine *s, GSM_CallDivert *divert)
 {
 	GSM_Error err;
 
@@ -1865,11 +1878,11 @@ GSM_Error GSM_GetScreenshot(GSM_StateMachine *s, GSM_BinaryPicture *picture)
 /**
  * Gets phone screenshot
  */
-GSM_Error GSM_Install(GSM_StateMachine *s, const char *ExtraPath)
+GSM_Error GSM_Install(GSM_StateMachine *s, const char *ExtraPath, gboolean Minimal)
 {
 	GSM_Error err;
 
-	err = s->Phone.Functions->Install(s, ExtraPath);
+	err = s->Phone.Functions->Install(s, ExtraPath, Minimal);
 	PRINT_LOG_ERROR(err);
 	return err;
 }
