@@ -115,9 +115,11 @@ int dbg_vprintf(GSM_Debug_Info *d, const char *format, va_list argp)
 	}
 
 	/* Flush buffers, this might be configurable, but it could cause drop of last log messages */
+#ifndef WIN32
 	if (d->df != NULL) {
 		fflush(d->df);
 	}
+#endif
 
 	return result;
 }
@@ -154,14 +156,12 @@ GSM_Error GSM_SetDebugFile(const char *info, GSM_Debug_Info *privdi)
 		case DL_TEXTERROR:
 		case DL_TEXTERRORDATE:
 			testfile = fopen(info,"a" COMMIT_FLAG);
-			if (!testfile) {
-				dbgprintf(privdi, "Can't open debug file\n");
-				return ERR_CANTOPENFILE;
-			}
-			fseek(testfile, 0, SEEK_END);
-			if (ftell(testfile) > 5000000) {
-				fclose(testfile);
-				testfile = fopen(info,"w" COMMIT_FLAG);
+			if (testfile != NULL) {
+				fseek(testfile, 0, SEEK_END);
+				if (ftell(testfile) > 5000000) {
+					fclose(testfile);
+					testfile = fopen(info,"w" COMMIT_FLAG);
+				}
 			}
 			break;
 		default:
@@ -189,35 +189,35 @@ gboolean GSM_SetDebugLevel(const char *info, GSM_Debug_Info *privdi)
 		privdi->dl = DL_NONE;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "nothing")) {
+	if (strcasecmp(info, "nothing") == 0) {
 		privdi->dl = DL_NONE;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "text")) {
+	if (strcasecmp(info, "text") == 0) {
 		privdi->dl = DL_TEXT;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "textall")) {
+	if (strcasecmp(info, "textall") == 0) {
 		privdi->dl = DL_TEXTALL;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "binary")) {
+	if (strcasecmp(info, "binary") == 0) {
 		privdi->dl = DL_BINARY;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "errors")) {
+	if (strcasecmp(info, "errors") == 0) {
 		privdi->dl = DL_TEXTERROR;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "textdate")) {
+	if (strcasecmp(info, "textdate") == 0) {
 		privdi->dl = DL_TEXTDATE;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "textalldate")) {
+	if (strcasecmp(info, "textalldate") == 0) {
 		privdi->dl = DL_TEXTALLDATE;
 		return TRUE;
 	}
-	if (!strcasecmp(info, "errorsdate")) {
+	if (strcasecmp(info, "errorsdate") == 0) {
 		privdi->dl = DL_TEXTERRORDATE;
 		return TRUE;
 	}
