@@ -212,6 +212,9 @@ typedef struct _GSM_User	 	GSM_User;
 #ifdef GSM_ENABLE_BLUETOOTHDEVICE
 #  include "device/bluetoth/bluetoth.h"
 #endif
+#ifndef WIN32
+#  include "device/proxy/proxy.h"
+#endif
 
 #include "debug.h"
 #include "gsmreply.h"
@@ -277,6 +280,12 @@ extern GSM_Device_Functions BlueToothDevice;
  */
 extern GSM_Device_Functions FBUSUSBDevice;
 #endif
+#ifndef WIN32
+/**
+ * Proxy device functions.
+ */
+extern GSM_Device_Functions ProxyDevice;
+#endif
 
 /**
  * Structure containing device specific data and pointer to device functions -
@@ -312,6 +321,12 @@ typedef struct {
 		 * Data for libusb-1.0 backend.
 		 */
 		GSM_Device_USBData		USB;
+#endif
+#ifndef WIN32
+		/**
+		 * Data for shell proxy.
+		 */
+		GSM_Device_ProxyData		Proxy;
 #endif
 	} Data;
 	/**
@@ -1292,6 +1307,10 @@ typedef struct {
 	 * Sets phone power state
 	 */
 	GSM_Error (*SetPower)	(GSM_StateMachine *s, gboolean on);
+	/**
+	 * Post connect hook
+	 */
+	GSM_Error (*PostConnect)	(GSM_StateMachine *s);
 } GSM_Phone_Functions;
 
 	extern GSM_Phone_Functions NAUTOPhone;
@@ -1453,10 +1472,10 @@ GSM_Error GSM_WaitFor			(GSM_StateMachine *s, unsigned const char *buffer,
 
 GSM_Error GSM_DispatchMessage		(GSM_StateMachine *s);
 
-void 	  GSM_DumpMessageLevel2		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
-void 	  GSM_DumpMessageLevel2Recv	(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
-void 	  GSM_DumpMessageLevel3		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
-void GSM_DumpMessageLevel3Recv(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void 	  GSM_DumpMessageText		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void 	  GSM_DumpMessageTextRecv	(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void 	  GSM_DumpMessageBinary		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void GSM_DumpMessageBinaryRecv(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
 
 
 void GSM_OSErrorInfo(GSM_StateMachine *s, const char *description);
