@@ -222,14 +222,22 @@ int DecodeWithUnicodeAlphabet(wchar_t src, unsigned char *dest)
 
 void DecodeUnicode (const unsigned char *src, char *dest)
 {
- 	int 		i=0,o=0;
- 	wchar_t 	wc;
+	int		i=0,o=0;
+	wchar_t		value, second;
 
- 	while (src[(2*i)+1]!=0x00 || src[2*i]!=0x00) {
- 		wc = src[(2*i)+1] | (src[2*i] << 8);
-		o += DecodeWithUnicodeAlphabet(wc, dest + o);
- 		i++;
- 	}
+	while (src[(2*i)+1]!=0x00 || src[2*i]!=0x00) {
+		value = src[i * 2] * 256 + src[i * 2 + 1];
+		/* Decode UTF-16 */
+		if (value >= 0xD800 && value <= 0xDBFF) {
+			second = src[(i + 1) * 2] * 256 + src[(i + 1) * 2 + 1];
+			if (second >= 0xDC00 && second <= 0xDFFF) {
+				i++;
+				value = ((value - 0xD800) << 10) + (second - 0xDC00) + 0x010000;
+			}
+		}
+		o += DecodeWithUnicodeAlphabet(value, dest + o);
+		i++;
+	}
 	dest[o]=0;
 }
 
@@ -997,15 +1005,14 @@ void AddBuffer(unsigned char 	*Destination,
 	       unsigned char 	*Source,
 	       size_t 		BitsToProcess)
 {
-	size_t i=0;
+	size_t i;
 
-	while (i!=BitsToProcess) {
+	for (i = 0; i < BitsToProcess; i++) {
 		if (GetBit(Source, i)) {
 			SetBit(Destination, (*CurrentBit)+i);
 		} else {
 			ClearBit(Destination, (*CurrentBit)+i);
 		}
-		i++;
 	}
 	(*CurrentBit) = (*CurrentBit) + BitsToProcess;
 }
@@ -1015,11 +1022,7 @@ void AddBufferByte(unsigned char *Destination,
 		   unsigned char Source,
 		   size_t		 BitsToProcess)
 {
-	unsigned char Byte;
-
-	Byte = Source;
-
-	AddBuffer(Destination, CurrentBit, &Byte, BitsToProcess);
+	AddBuffer(Destination, CurrentBit, &Source, BitsToProcess);
 }
 
 void GetBuffer(unsigned char *Source,
@@ -1319,7 +1322,7 @@ GSM_Error MyGetLine(char *Buffer, size_t *Pos, char *OutBuffer, size_t MaxLen, s
 			} else {
 				if (MergeLines) {
 					/* (Quote printable new line) Does string end with = ? */
-					if (OutBuffer[pos - 1] == '=' && quoted_printable) {
+					if (quoted_printable && pos > 0 && OutBuffer[pos - 1] == '=') {
 						pos--;
 						OutBuffer[pos] = 0;
 						skip = TRUE;
@@ -1472,18 +1475,18 @@ int EncodeWithUTF8Alphabet(unsigned long src, unsigned char *ret)
 		ret[0] = 192 + (src / 64);
 		ret[1] = 128 + (src % 64);
 		return 2;
-	} else if (src < 0x1000) {
-		ret[1] = 224 + (src / (64 * 64));
+	} else if (src < 0x10000) {
+		ret[0] = 224 + (src / (64 * 64));
 		ret[1] = 128 + ((src / 64) % 64);
 		ret[2] = 128 + (src % 64);
 		return 3;
-	} else if (src < 0x20000) {
+	} else if (src < 0x200000) {
 		ret[0] = 240 + (src / (64 * 64 * 64));
 		ret[1] = 128 + ((src / (64 * 64)) % 64);
 		ret[2] = 128 + ((src / 64) % 64);
 		ret[3] = 128 + (src % 64);
 		return 4;
-	} else if (src < 0x400000) {
+	} else if (src < 0x4000000) {
 		ret[0] = 248 + (src / (64 * 64 * 64 * 64));
 		ret[1] = 128 + ((src / (64 * 64 * 64)) % 64);
 		ret[2] = 128 + ((src / (64 * 64)) % 64);
@@ -1561,6 +1564,7 @@ gboolean EncodeUTF8(char *dest, const unsigned char *src)
 		if (value >= 0xD800 && value <= 0xDBFF && (i + 1) < len) {
 			second = src[(i + 1) * 2] * 256 + src[(i + 1) * 2 + 1];
 			if (second >= 0xDC00 && second <= 0xDFFF) {
+				i++;
 				value = ((value - 0xD800) << 10) + (second - 0xDC00) + 0x010000;
 			}
 		}
@@ -1693,6 +1697,7 @@ void DecodeXMLUTF8(unsigned char *dest, const char *src, int len)
 	}
 	if (src == NULL) {
 		*dest = 0;
+		free(tmp);
 		return;
 	}
 
@@ -1705,7 +1710,7 @@ void DecodeXMLUTF8(unsigned char *dest, const char *src, int len)
 		/* Skip ampersand */
 		pos++;
 		/* Detect end of string */
-		if (pos == 0) break;
+		if (*pos == 0) break;
 		/* Find entity length */
 		pos_end = strchr(pos, ';');
 		if (pos_end - pos > 6 || pos_end == NULL) {
@@ -1721,9 +1726,9 @@ void DecodeXMLUTF8(unsigned char *dest, const char *src, int len)
 		/* Create entity */
 		/* strndup would be better, but not portable */
 		entity = strdup(pos);
+		if (entity == NULL) break;
 		entity[pos_end - pos] = 0;
 		dbgprintf(NULL, "Found XML entity: %s\n", entity);
-		if (entity == NULL) break;
 		if (entity[0] == '#') {
 			if (entity[1] == 'x' || entity[1] == 'X') {
 				c = strtoull(entity + 2, NULL, 16);
