@@ -18,6 +18,8 @@
 #  define WIN32_LEAN_AND_MEAN
 #  include <windows.h>
 #  include <locale.h>
+#  define gmtime_r(x, y) gmtime_s(y, x)
+#  define localtime_r(x, y) localtime_s(y, x)
 #endif
 #ifdef HAVE_SYS_UTSNAME_H
 #  include <sys/utsname.h>
@@ -142,12 +144,12 @@ char *DayOfWeek (unsigned int year, unsigned int month, unsigned int day)
 }
 
 int GSM_GetLocalTimezoneOffset() {
-	struct tm *tg, *tl;
+	struct tm tg, tl;
 	time_t now = time(NULL);
-	tg = gmtime(&now);
-	tl = localtime(&now);
+	gmtime_r(&now, &tg);
+	localtime_r(&now, &tl);
 	// Returns offset including daylight saving (found as boolean in tl.tm_isdst).
-	return (tl->tm_hour - tg->tm_hour) * 3600 + (tl->tm_min - tg->tm_min) * 60 + (tl->tm_sec - tg->tm_sec);
+	return mktime(&tl) - mktime(&tg);
 }
 
 void GSM_DateTimeToTimestamp(GSM_DateTime *Date, char *str)
@@ -255,7 +257,6 @@ void GetTimeDifference(unsigned long diff, GSM_DateTime *DT, gboolean Plus, int
 	}
 
 	Fill_GSM_DateTime(DT, t_time);
-	DT->Year = DT->Year;
 	dbgprintf(NULL, "EndTime: %02i-%02i-%04i %02i:%02i:%02i\n",
 		DT->Day,DT->Month,DT->Year,DT->Hour,DT->Minute,DT->Second);
 }
