@@ -1691,6 +1691,7 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(GSM_Debug_Info *di, char *Buffer, size_t *Po
 
 	Calendar->EntriesNum 	= 0;
 	ToDo->EntriesNum 	= 0;
+	ToDo->Location	 	= 0;
 	lBuffer = strlen(Buffer);
 	trigger.Timezone = -999 * 3600;
 
@@ -1982,10 +1983,17 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(GSM_Debug_Info *di, char *Buffer, size_t *Po
 				ToDo->EntriesNum++;
 			}
 			if (ReadVCALText(Line, "PRIORITY", Buff, ToDoVer == Mozilla_VToDo, NULL)) {
-				if (atoi(DecodeUnicodeString(Buff))==3) ToDo->Priority = GSM_Priority_Low;
-				else if (atoi(DecodeUnicodeString(Buff))==2) ToDo->Priority = GSM_Priority_Medium;
-				else if (atoi(DecodeUnicodeString(Buff))==1) ToDo->Priority = GSM_Priority_High;
-				else ToDo->Priority = GSM_Priority_None;
+				if (ToDoVer == Mozilla_VToDo) {
+					if (atoi(DecodeUnicodeString(Buff))>=9) ToDo->Priority = GSM_Priority_High;
+					else if (atoi(DecodeUnicodeString(Buff))>=5) ToDo->Priority = GSM_Priority_Medium;
+					else if (atoi(DecodeUnicodeString(Buff))>=1) ToDo->Priority = GSM_Priority_Low;
+					else ToDo->Priority = GSM_Priority_None;
+				} else {
+					if (atoi(DecodeUnicodeString(Buff))==3) ToDo->Priority = GSM_Priority_Low;
+					else if (atoi(DecodeUnicodeString(Buff))==2) ToDo->Priority = GSM_Priority_Medium;
+					else if (atoi(DecodeUnicodeString(Buff))==1) ToDo->Priority = GSM_Priority_High;
+					else ToDo->Priority = GSM_Priority_None;
+				}
 			}
 			if (strstr(Line,"STATUS:COMPLETED")) {
 				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_COMPLETED;
