@@ -34,40 +34,181 @@ unsigned char GSM_MakeSMSIDFromTime(void)
 	return retval;
 }
 
-void GSM_Find_Free_Used_SMS2(GSM_Debug_Info *di, GSM_Coding_Type Coding,GSM_SMSMessage SMS, size_t *UsedText, size_t *FreeText, size_t *FreeBytes)
+void GSM_Find_Free_Used_SMS2(GSM_Debug_Info *di, GSM_Coding_Type Coding,GSM_SMSMessage *SMS, size_t *UsedText, size_t *FreeText, size_t *FreeBytes)
 {
 	size_t UsedBytes = 0;
 
 	switch (Coding) {
 	case SMS_Coding_Default_No_Compression:
-		FindDefaultAlphabetLen(SMS.Text,&UsedBytes,UsedText,500);
+		FindDefaultAlphabetLen(SMS->Text,&UsedBytes,UsedText,500);
 		UsedBytes = *UsedText * 7 / 8;
 		if (UsedBytes * 8 / 7 != *UsedText) UsedBytes++;
-		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS.UDH.Length - UsedBytes;
-		*FreeText = (GSM_MAX_8BIT_SMS_LENGTH - SMS.UDH.Length) * 8 / 7 - *UsedText;
+		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS->UDH.Length - UsedBytes;
+		*FreeText = (GSM_MAX_8BIT_SMS_LENGTH - SMS->UDH.Length) * 8 / 7 - *UsedText;
 		break;
 	case SMS_Coding_Unicode_No_Compression:
-		*UsedText = UnicodeLength(SMS.Text);
+		*UsedText = UnicodeLength(SMS->Text);
 		UsedBytes = *UsedText * 2;
-		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS.UDH.Length - UsedBytes;
+		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS->UDH.Length - UsedBytes;
 		*FreeText = *FreeBytes / 2;
 		break;
 	case SMS_Coding_8bit:
-		*UsedText = UsedBytes = SMS.Length;
-		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS.UDH.Length - UsedBytes;
+		*UsedText = UsedBytes = SMS->Length;
+		*FreeBytes = GSM_MAX_8BIT_SMS_LENGTH - SMS->UDH.Length - UsedBytes;
 		*FreeText = *FreeBytes;
 		break;
 	default:
 		break;
 	}
 	smfprintf(di, "UDH len %i, UsedBytes %ld, FreeText %ld, UsedText %ld, FreeBytes %ld\n",
-		SMS.UDH.Length,
+		SMS->UDH.Length,
 		(long)UsedBytes,
 		(long)*FreeText,
 		(long)*UsedText,
 		(long)*FreeBytes);
 }
 
+unsigned int ReassembleCharacter(char *Buffer, size_t character_index)
+{
+	size_t offset = character_index * 2;
+
+	return (
+	  (unsigned int) ((unsigned char) Buffer[offset] << 8)
+	    + (unsigned char) Buffer[offset + 1]
+	);
+}
+
+int AlignIfSurrogatePair(GSM_Debug_Info	*di,
+			 size_t		*Copy,
+			 char		*Buffer,
+			 size_t		BufferLen)
+{
+	int rv = 0;
+	unsigned int n;
+
+	/* Precondition:
+	 *   Resulting copy must always be non-zero. */
+
+	if (*Copy <= 1) {
+		return rv;
+	}
+
+	/* Don't split a UTF-16 surrogate pair:
+	 *   If the final code unit to be copied is a lead surrogate, save
+	 *   it for the next message segment. This allows recipients to view
+	 *   the proper four-byte UTF-16 character even if they're unable to
+	 *   reassemble the message (e.g. if a telecom strips off the UDH). */
+
+	n = ReassembleCharacter(Buffer, *Copy - 1);
+
+	/* UTF-16 leading surrogate:
+	 *   First character in pair is always between U+D800 and U+DBFF */
+
+	if (n >= 0xd800 && n <= 0xdbff) {
+		*Copy -= 1;
+		++rv;
+	}
+
+	return rv;
+}
+
+int AlignIfCombinedCharacter(GSM_Debug_Info	*di,
+			      size_t		*Copy,
+			      char		*Buffer,
+			      size_t		BufferLen)
+{
+	int rv = 0;
+	unsigned int n;
+
+	/* Precondition:
+	 *   If we only have one character to copy, or if there isn't any
+	 *   code unit following our copy window, don't change anything. */
+
+	if (*Copy <= 1 || *Copy >= BufferLen) {
+		return rv;
+	}
+
+	/* Don't split up a combining sequence:
+	 *   Peek at the next message segment to see if it begins with
+	 *   a combining character (e.g. a discritical mark). If it does,
+	 *   push the final character of this message segment in to the
+	 *   next message segment. This ensures that the recipient can
+	 *   visually combine the sequence, even if reassembly fails. */
+
+	n = ReassembleCharacter(Buffer, *Copy);
+
+	/* Unicode combining characters:
+	 *   Combining Half Marks (U+FE20 - U+FE2F)
+	 *   Combining Diacritical Marks (U+300 - U+36F)
+	 *   Combining Diacritical Marks Extended (U+1AB0 - U+1AFF)
+	 *   Combining Diacritical Marks Supplement (U+1DC0 - U+1DFF)
+	 *   Combining Diacritical Marks for Symbols (U+20D0 - U+20FF) */
+
+	if ((n >= 0xfe20 && n <= 0xfe2f) ||
+	    (n >= 0x300 && n <= 0x36f) || (n >= 0x1ab0 && n <= 0x1aff) ||
+	    (n >= 0x1dc0 && n <= 0x1dff) || (n >= 0x20d0 && n <= 0x20ff)) {
+		*Copy -= 1;
+		++rv;
+	}
+
+	return rv;
+}
+
+int AlignIfCombinedSurrogate(GSM_Debug_Info	*di,
+			     size_t		*Copy,
+			     char		*Buffer,
+			     size_t		BufferLen)
+{
+	int rv = 0;
+	unsigned int l1, l2, r1, r2;
+
+	/* Precondition:
+	 *   If we have two or fewer characters to copy, omitting two
+	 *   of them would cause us to send empty message segments. If
+	 *   there aren't at least two characters remaining *after* the
+	 *   copy boundary, then there can't possibly be space for a
+	 *   second surrogate pair there. In either case, send as-is. */
+
+	if (*Copy <= 2 || (*Copy + 2) >= BufferLen) {
+		return rv;
+	}
+
+	/* Fetch characters:
+	 *   We retrieve two UTF-16 characters directly preceeding the
+	 *   copy boundary, and two directly following the copy boundary. */
+
+	l1 = ReassembleCharacter(Buffer, *Copy - 2);
+	l2 = ReassembleCharacter(Buffer, *Copy - 1);
+	r1 = ReassembleCharacter(Buffer, *Copy);
+	r2 = ReassembleCharacter(Buffer, *Copy + 1);
+
+	/* Regional Indicator Symbol (U+1F1E6 - U+1F1FF)
+	 *   UTF-16 surrogate pairs: 0xd83c 0xdde6 - 0xd83c 0xddff */
+
+	if (l1 == 0xd83c && r1 == 0xd83c &&
+	    l2 >= 0xdde6 && l2 <= 0xddff && r2 >= 0xdde6 && r2 <= 0xddff) {
+		*Copy -= 2;
+		rv += 2;
+	}
+
+	return rv;
+}
+
+int AlignSegmentForContent(GSM_Debug_Info	*di,
+			   size_t		*Copy,
+			   char			*Buffer,
+			   size_t		BufferLen)
+{
+	int rv = 0;
+
+	if (!(rv += AlignIfSurrogatePair(di, Copy, Buffer, BufferLen))) {
+		rv += AlignIfCombinedCharacter(di, Copy, Buffer, BufferLen);
+	}
+
+	rv += AlignIfCombinedSurrogate(di, Copy, Buffer, BufferLen);
+	return rv;
+}
+
 GSM_Error GSM_AddSMS_Text_UDH(GSM_Debug_Info *di,
 				GSM_MultiSMSMessage 	*SMS,
 		      		GSM_Coding_Type		Coding,
@@ -78,17 +219,23 @@ GSM_Error GSM_AddSMS_Text_UDH(GSM_Debug_Info *di,
 		      		size_t			*CopiedText,
 		      		size_t			*CopiedSMSText)
 {
-	size_t FreeText,FreeBytes,Copy,i,j;
+	size_t FreeText=0,FreeBytes=0,Copy,i,j;
 
 	smfprintf(di, "Checking used: ");
-	GSM_Find_Free_Used_SMS2(di, Coding,SMS->SMS[SMS->Number], UsedText, &FreeText, &FreeBytes);
+	GSM_Find_Free_Used_SMS2(
+		di, Coding, &(SMS->SMS[SMS->Number]),
+		UsedText, &FreeText, &FreeBytes
+	);
 
 	if (UDH) {
 		smfprintf(di, "Adding UDH\n");
 		if (FreeBytes - BufferLen <= 0) {
 			smfprintf(di, "Going to the new SMS\n");
 			SMS->Number++;
-			GSM_Find_Free_Used_SMS2(di, Coding,SMS->SMS[SMS->Number], UsedText, &FreeText, &FreeBytes);
+			GSM_Find_Free_Used_SMS2(
+				di, Coding, &(SMS->SMS[SMS->Number]),
+				UsedText, &FreeText, &FreeBytes
+			);
 		}
 		if (SMS->SMS[SMS->Number].UDH.Length == 0) {
 			SMS->SMS[SMS->Number].UDH.Length  = 1;
@@ -104,7 +251,10 @@ GSM_Error GSM_AddSMS_Text_UDH(GSM_Debug_Info *di,
 		if (FreeText == 0) {
 			smfprintf(di, "Going to the new SMS\n");
 			SMS->Number++;
-			GSM_Find_Free_Used_SMS2(di, Coding,SMS->SMS[SMS->Number], UsedText, &FreeText, &FreeBytes);
+			GSM_Find_Free_Used_SMS2(
+				di, Coding, &(SMS->SMS[SMS->Number]),
+				UsedText, &FreeText, &FreeBytes
+			);
 		}
 
 		Copy = FreeText;
@@ -125,6 +275,7 @@ GSM_Error GSM_AddSMS_Text_UDH(GSM_Debug_Info *di,
 			SMS->SMS[SMS->Number].Length += i;
 			break;
 		case SMS_Coding_Unicode_No_Compression:
+			AlignSegmentForContent(di, &Copy, Buffer, BufferLen);
 			SMS->SMS[SMS->Number].Text[UnicodeLength(SMS->SMS[SMS->Number].Text)*2+Copy*2]   = 0;
 			SMS->SMS[SMS->Number].Text[UnicodeLength(SMS->SMS[SMS->Number].Text)*2+Copy*2+1] = 0;
 			memcpy(SMS->SMS[SMS->Number].Text+UnicodeLength(SMS->SMS[SMS->Number].Text)*2,Buffer,Copy*2);
@@ -143,7 +294,10 @@ GSM_Error GSM_AddSMS_Text_UDH(GSM_Debug_Info *di,
 	}
 
 	smfprintf(di, "Checking at the end: ");
-	GSM_Find_Free_Used_SMS2(di, Coding,SMS->SMS[SMS->Number], UsedText, &FreeText, &FreeBytes);
+	GSM_Find_Free_Used_SMS2(
+		di, Coding, &(SMS->SMS[SMS->Number]),
+		UsedText, &FreeText, &FreeBytes
+	);
 
 	return ERR_NONE;
 }
@@ -205,12 +359,15 @@ void GSM_SMSCounter(GSM_Debug_Info *di,
 		    int 		*SMSNum,
 		    size_t 		*CharsLeft)
 {
-	size_t			UsedText,FreeBytes;
+	size_t			UsedText=0,FreeBytes=0;
 	GSM_MultiSMSMessage 	MultiSMS;
 
 	MultiSMS.Number = 0;
 	GSM_MakeMultiPartSMS(di, &MultiSMS,MessageBuffer,UnicodeLength(MessageBuffer),UDHType,Coding,-1,FALSE);
-	GSM_Find_Free_Used_SMS2(di, Coding,MultiSMS.SMS[MultiSMS.Number-1], &UsedText, CharsLeft, &FreeBytes);
+	GSM_Find_Free_Used_SMS2(
+		di, Coding, &(MultiSMS.SMS[MultiSMS.Number-1]),
+		&UsedText, CharsLeft, &FreeBytes
+	);
 	*SMSNum = MultiSMS.Number;
 }
 
@@ -344,8 +501,9 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 				 GSM_MultiPartSMSInfo		*Info,
 			    	 GSM_MultiSMSMessage		*SMS)
 {
-	unsigned char	Buffer[GSM_MAX_SMS_LENGTH*2*GSM_MAX_MULTI_SMS];
-	unsigned char	Buffer2[GSM_MAX_SMS_LENGTH*2*GSM_MAX_MULTI_SMS];
+	unsigned char	*Buffer;
+	unsigned char	*Buffer2;
+	size_t		buffer_size = GSM_MAX_SMS_LENGTH * 2 * GSM_MAX_MULTI_SMS;
 	int		i, Class = -1, j;
 	size_t p;
 	size_t Length = 0, smslen;
@@ -358,6 +516,16 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 
 	if (Info->EntriesNum == 0) return ERR_EMPTY;
 
+	Buffer = malloc(buffer_size);
+	if (Buffer == NULL) {
+		return ERR_MOREMEMORY;
+	}
+	Buffer2 = malloc(buffer_size);
+	if (Buffer2 == NULL) {
+		free(Buffer);
+		return ERR_MOREMEMORY;
+	}
+
 	SMS->Number = 0;
 
 	if (Info->Entries[0].ID == SMS_AlcatelSMSTemplateName) {
@@ -400,11 +568,13 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 			Length 			= Length + smslen;
 			break;
 		default:
-			return ERR_UNKNOWN;
+			error = ERR_UNKNOWN;
+			goto out;
 		}
 		}
 		Buffer[0] = Buffer[0] * 2;
-		return GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Buffer,ALCATELTDD_SMSTEMPLATE);
+		error = GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Buffer,ALCATELTDD_SMSTEMPLATE);
+		goto out;
 	}
 
 	for (i=0;i<Info->EntriesNum;i++) {
@@ -451,20 +621,26 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 	}
 	if (EMS) {
 		error=GSM_EncodeEMSMultiPartSMS(di, Info,SMS,UDH_NoUDH);
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			goto out;
+		}
 		if (SMS->Number != 1) {
 			SMS->Number = 0;
 			for (i=0;i<Info->EntriesNum;i++) {
 				if (Info->Entries[i].ID == SMS_ConcatenatedTextLong16bit) {
-					return GSM_EncodeEMSMultiPartSMS(di, Info,SMS,UDH_ConcatenatedMessages);
+					error = GSM_EncodeEMSMultiPartSMS(di, Info,SMS,UDH_ConcatenatedMessages);
+					goto out;
 				}
 			}
-			return GSM_EncodeEMSMultiPartSMS(di, Info,SMS,UDH_ConcatenatedMessages16bit);
+			error = GSM_EncodeEMSMultiPartSMS(di, Info,SMS,UDH_ConcatenatedMessages16bit);
 		}
-		return error;
+		goto out;
 	}
 
-	if (Info->EntriesNum != 1) return ERR_UNKNOWN;
+	if (Info->EntriesNum != 1) {
+		error = ERR_UNKNOWN;
+		goto out;
+	}
 
 	switch (Info->Entries[0].ID) {
 	case SMS_AlcatelMonoBitmapLong:
@@ -472,7 +648,8 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 		Buffer[1] = Info->Entries[0].Bitmap->Bitmap[0].BitmapHeight;
 		PHONE_EncodeBitmap(GSM_AlcatelBMMIPicture, Buffer+2, &Info->Entries[0].Bitmap->Bitmap[0]);
 		Length = PHONE_GetBitmapSize(GSM_AlcatelBMMIPicture,Info->Entries[0].Bitmap->Bitmap[0].BitmapWidth,Info->Entries[0].Bitmap->Bitmap[0].BitmapHeight)+2;
-		return GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Bitmap->Bitmap[0].Text,ALCATELTDD_PICTURE);
+		error = GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Bitmap->Bitmap[0].Text,ALCATELTDD_PICTURE);
+		goto out;
 	case SMS_AlcatelMonoAnimationLong:
 		/* Number of sequence words */
 		Buffer[0] = (Info->Entries[0].Bitmap->Number+1) % 256;
@@ -498,11 +675,12 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 			PHONE_EncodeBitmap(GSM_AlcatelBMMIPicture, Buffer+Length, &Info->Entries[0].Bitmap->Bitmap[i]);
 			Length += PHONE_GetBitmapSize(GSM_AlcatelBMMIPicture,Info->Entries[0].Bitmap->Bitmap[i].BitmapWidth,Info->Entries[0].Bitmap->Bitmap[i].BitmapHeight);
 		}
-		return GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Bitmap->Bitmap[0].Text,ALCATELTDD_ANIMATION);
+		error = GSM_EncodeAlcatelMultiPartSMS(di, SMS,Buffer,Length,Info->Entries[0].Bitmap->Bitmap[0].Text,ALCATELTDD_ANIMATION);
+		goto out;
 	case SMS_MMSIndicatorLong:
 		Class	= 1;
 		UDH	= UDH_MMSIndicatorLong;
-		GSM_EncodeMMSIndicatorSMSText(Buffer,&Length,*Info->Entries[0].MMSIndicator);
+		GSM_EncodeMMSIndicatorSMSText(Buffer,&Length,Info->Entries[0].MMSIndicator);
 		break;
 	case SMS_WAPIndicatorLong:
 		Class	= 1;
@@ -572,75 +750,78 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 		NOKIA_EncodeWAPMMSSettingsSMSText(Buffer,&Length,Info->Entries[0].Settings,TRUE);
 		break;
 	case SMS_NokiaVCARD10Long:
+		Coding = SMS_Coding_Default_No_Compression;
 		/* is 1 SMS ? 8 = length of ..SCKE2 */
 		if (Length<=GSM_MAX_SMS_CHARS_LENGTH-8) {
 			sprintf(Buffer,"//SCKE2 ");
 			Length = 8;
-			Coding = SMS_Coding_Default_No_Compression;
 		} else {
 			UDH = UDH_NokiaPhonebookLong;
-			Coding = SMS_Coding_8bit;
 		}
-		error = GSM_EncodeVCARD(di, Buffer, sizeof(Buffer), &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard10);
-		if (error != ERR_NONE) return error;
-		if (Coding == SMS_Coding_Default_No_Compression) {
-			memcpy(Buffer2,Buffer,Length);
-			EncodeUnicode(Buffer,Buffer2,Length);
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard10);
+		if (error != ERR_NONE) {
+			goto out;
 		}
+		memcpy(Buffer2,Buffer,Length);
+		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_NokiaVCARD21Long:
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard21);
+		if (error != ERR_NONE) {
+			goto out;
+		}
+		Coding = SMS_Coding_Default_No_Compression;
 		/* Is 1 SMS ? 12 = length of ..SCKL23F4 */
-		if (Length<=GSM_MAX_SMS_CHARS_LENGTH-12) {
+		if (Length <= GSM_MAX_SMS_CHARS_LENGTH - 12) {
 			sprintf(Buffer,"//SCKL23F4%c%c",13,10);
 			Length = 12;
-			Coding = SMS_Coding_Default_No_Compression;
 		} else {
 			UDH = UDH_NokiaPhonebookLong;
-			Coding = SMS_Coding_8bit;
-		}
-		error = GSM_EncodeVCARD(di, Buffer, sizeof(Buffer), &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard21);
-		if (error != ERR_NONE) return error;
-		if (Coding == SMS_Coding_Default_No_Compression) {
-			memcpy(Buffer2,Buffer,Length);
-			EncodeUnicode(Buffer,Buffer2,Length);
 		}
+		memcpy(Buffer2,Buffer,Length);
+		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_VCARD10Long:
-		error = GSM_EncodeVCARD(di, Buffer, sizeof(Buffer), &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard10);
-		if (error != ERR_NONE) return error;
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard10);
+		if (error != ERR_NONE) {
+			goto out;
+		}
 		if (Length>GSM_MAX_SMS_CHARS_LENGTH) UDH = UDH_ConcatenatedMessages;
 		Coding = SMS_Coding_Default_No_Compression;
 		memcpy(Buffer2,Buffer,Length);
 		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_VCARD21Long:
-		error = GSM_EncodeVCARD(di, Buffer, sizeof(Buffer), &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard21);
-		if (error != ERR_NONE) return error;
+		error = GSM_EncodeVCARD(di, Buffer, buffer_size, &Length,Info->Entries[0].Phonebook,TRUE,Nokia_VCard21);
+		if (error != ERR_NONE) {
+			goto out;
+		}
 		if (Length>GSM_MAX_SMS_CHARS_LENGTH) UDH = UDH_ConcatenatedMessages;
 		Coding = SMS_Coding_Default_No_Compression;
 		memcpy(Buffer2,Buffer,Length);
 		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_NokiaVCALENDAR10Long:
+		error=GSM_EncodeVCALENDAR(Buffer, buffer_size,&Length,Info->Entries[0].Calendar,TRUE,Nokia_VCalendar);
+		if (error != ERR_NONE) {
+			goto out;
+		}
+		Coding = SMS_Coding_Default_No_Compression;
 		/* Is 1 SMS ? 8 = length of ..SCKE4 */
-		if (Length<=GSM_MAX_SMS_CHARS_LENGTH-8) {
+		if (Length <= GSM_MAX_SMS_CHARS_LENGTH - 8) {
 			sprintf(Buffer,"//SCKE4 ");
 			Length = 8;
-			Coding = SMS_Coding_Default_No_Compression;
 		} else {
 			UDH = UDH_NokiaCalendarLong;
-			Coding = SMS_Coding_8bit;
-		}
-		error=GSM_EncodeVCALENDAR(Buffer, sizeof(Buffer),&Length,Info->Entries[0].Calendar,TRUE,Nokia_VCalendar);
-		if (error != ERR_NONE) return error;
-		if (Coding == SMS_Coding_Default_No_Compression) {
-			memcpy(Buffer2,Buffer,Length);
-			EncodeUnicode(Buffer,Buffer2,Length);
 		}
+		memcpy(Buffer2,Buffer,Length);
+		EncodeUnicode(Buffer,Buffer2,Length);
 		break;
 	case SMS_NokiaVTODOLong:
-		error=GSM_EncodeVTODO(Buffer, sizeof(Buffer),&Length,Info->Entries[0].ToDo,TRUE,Nokia_VToDo);
-		if (error != ERR_NONE) return error;
+		error=GSM_EncodeVTODO(Buffer, buffer_size,&Length,Info->Entries[0].ToDo,TRUE,Nokia_VToDo);
+		if (error != ERR_NONE) {
+			goto out;
+		}
 		UDH = UDH_NokiaCalendarLong;
 		Coding = SMS_Coding_Default_No_Compression;
 		memcpy(Buffer2,Buffer,Length);
@@ -736,7 +917,11 @@ GSM_Error GSM_EncodeMultiPartSMS(GSM_Debug_Info *di,
 		break;
 	}
 	GSM_MakeMultiPartSMS(di, SMS,Buffer,Length,UDH,Coding,Class,Info->ReplaceMessage);
-	return ERR_NONE;
+	error = ERR_NONE;
+out:
+	free(Buffer);
+	free(Buffer2);
+	return error;
 }
 
 void GSM_ClearMultiPartSMSInfo(GSM_MultiPartSMSInfo *Info)
@@ -1106,7 +1291,7 @@ gboolean GSM_DecodeMultiPartSMS(GSM_Debug_Info *di,
 {
 	int 			i;
 	unsigned int		j;
-	gboolean 			emsexist = FALSE;
+	gboolean 			emsexist = FALSE, result;
 	GSM_SiemensOTASMSInfo	SiemensInfo;
 
 	GSM_ClearMultiPartSMSInfo(Info);
@@ -1134,12 +1319,13 @@ gboolean GSM_DecodeMultiPartSMS(GSM_Debug_Info *di,
 		Info->Entries[0].File->Buffer 	= NULL;
 		Info->Entries[0].File->Used 	= 0;
 		for (i=0;i<SMS->Number;i++) {
-			GSM_DecodeSiemensOTASMS(di, &SiemensInfo,&SMS->SMS[i]);
-			j = SiemensInfo.AllDataLen - Info->Entries[0].File->Used;
-			if (j>SiemensInfo.DataLen) j = SiemensInfo.DataLen;
-			Info->Entries[0].File->Buffer = (unsigned char *)realloc(Info->Entries[0].File->Buffer,j+Info->Entries[0].File->Used);
-			memcpy(Info->Entries[0].File->Buffer+Info->Entries[0].File->Used,SiemensInfo.Data,j);
-			Info->Entries[0].File->Used += j;
+			if (GSM_DecodeSiemensOTASMS(di, &SiemensInfo,&SMS->SMS[i])) {
+				j = SiemensInfo.AllDataLen - Info->Entries[0].File->Used;
+				if (j>SiemensInfo.DataLen) j = SiemensInfo.DataLen;
+				Info->Entries[0].File->Buffer = (unsigned char *)realloc(Info->Entries[0].File->Buffer,j+Info->Entries[0].File->Used);
+				memcpy(Info->Entries[0].File->Buffer+Info->Entries[0].File->Used,SiemensInfo.Data,j);
+				Info->Entries[0].File->Used += j;
+			}
 		}
 		if (SiemensInfo.AllDataLen == Info->Entries[0].File->Used) {
 			Info->Entries[0].ID 	= SMS_SiemensFile;
@@ -1197,6 +1383,19 @@ gboolean GSM_DecodeMultiPartSMS(GSM_Debug_Info *di,
 	    SMS->SMS[0].UDH.Type == UDH_ConcatenatedMessages16bit) {
 		return GSM_DecodeLinkedText(di, Info, SMS);
 	}
+	/* Nokia vCard/vCalendar */
+	if (SMS->SMS[0].UDH.Type == UDH_NokiaCalendarLong ||
+	    SMS->SMS[0].UDH.Type == UDH_NokiaPhonebookLong) {
+		result = GSM_DecodeLinkedText(di, Info, SMS);
+		if (result) {
+			if (SMS->SMS[0].UDH.Type == UDH_NokiaPhonebookLong) {
+				Info->Entries[0].ID = SMS_NokiaVCARD10Long;
+			} else {
+				Info->Entries[0].ID = SMS_NokiaVCALENDAR10Long;
+			}
+		}
+		return result;
+	}
 	/* MMS indication */
 	if (SMS->SMS[0].UDH.Type == UDH_MMSIndicatorLong) {
 		return GSM_DecodeMMSIndication(di, Info, SMS);
