@@ -1,5 +1,5 @@
 /* (c) 2002-2004 by Marcin Wiacek and Joergen Thomsen */
-/* Copyright (c) 2009 - 2011 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
 
 #ifndef __core_h_
 #define __core_h_
@@ -17,7 +17,7 @@
 
 #define SMSD_SHM_KEY (0xface)
 #define SMSD_SHM_VERSION (1)
-#define SMSD_DB_VERSION (14)
+#define SMSD_DB_VERSION (15)
 
 #include "log.h"
 
@@ -58,6 +58,7 @@ typedef struct {
 	GSM_Error	(*CreateOutboxSMS)    (GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config, char *NewID);
 	GSM_Error	(*AddSentSMSInfo)     (GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config, char *ID, int Part, GSM_SMSDSendingError err, int TPMR);
 	GSM_Error	(*RefreshSendStatus)  (GSM_SMSDConfig *Config, char *ID);
+	GSM_Error	(*UpdateRetries)  (GSM_SMSDConfig *Config, char *ID);
 	/**
 	 * Updates phone status in service backend. Please note that
 	 * this can not talk to the phone.
@@ -85,6 +86,7 @@ struct _GSM_SMSDConfig {
 	const char	*PhoneID;
 	const char   *RunOnReceive;
 	const char   *RunOnFailure; /* run this command on phone communication failure */
+	const char   *RunOnSent; /* run this command when an SMS has been sent successfully */
 	gboolean checksecurity;
 	gboolean hangupcalls;
 	gboolean checkbattery;
@@ -105,6 +107,7 @@ struct _GSM_SMSDConfig {
 	unsigned char 	SMSID[200],	 prevSMSID[200];
 	GSM_SMSC	SMSC, SMSCCache;
 	const char	*skipsmscnumber;
+	int		IgnoredMessages;
 
 #if defined(HAVE_MYSQL_MYSQL_H) || defined(HAVE_POSTGRESQL_LIBPQ_FE_H) || defined(LIBDBI_FOUND) || defined(ODBC_FOUND)
 	/* options for SQL database */
