@@ -1,7 +1,7 @@
 /**
  * SMSD message inject program
  */
-/* Copyright (c) 2009 - 2011 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
 /* Licensend under GNU GPL 2 */
 
 #include <gammu-smsd.h>
@@ -28,7 +28,6 @@ const char default_config[] = "/etc/gammu-smsdrc";
 NORETURN void version(void)
 {
 	printf("Gammu-smsd-inject version %s\n", GAMMU_VERSION);
-	printf("Built %s on %s using %s\n", __TIME__, __DATE__, GetCompiler());
 	printf("Compiled in features:\n");
 	printf("OS support:\n");
 #ifdef HAVE_SHM
@@ -56,9 +55,9 @@ NORETURN void version(void)
 	printf("  - %s\n", "ODBC");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2011 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2015 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
-	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
+	printf("License GPLv2: GNU GPL version 2 <https://spdx.org/licenses/GPL-2.0>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
@@ -121,13 +120,13 @@ int process_commandline(int argc, char **argv, SMSD_Parameters * params)
 	while ((opt = getopt(argc, argv, "+hvc:lL")) != -1) {
 #else
 	/* Poor mans getopt replacement */
-	int i, optind = -1;
+	int i;
 
 #define optarg argv[++i]
 
 	for (i = 1; i < argc; i++) {
 		if (strlen(argv[i]) != 2 || argv[i][0] != '-') {
-			wrong_params();
+			return i;
 		}
 		opt = argv[i][1];
 #endif
@@ -150,20 +149,16 @@ int process_commandline(int argc, char **argv, SMSD_Parameters * params)
 				help();
 				exit(0);
 			default:
-#if defined(HAVE_GETOPT) || defined(HAVE_GETOPT_LONG)
 				wrong_params();
-#else
-				optind = 1;
-#endif
 				break;
 		}
-#if !defined(HAVE_GETOPT) && !defined(HAVE_GETOPT_LONG)
-		if (optind != -1)
-			break;
-#endif
 	}
 
+#if defined(HAVE_GETOPT_LONG) || defined(HAVE_GETOPT)
 	return optind;
+#else
+	return i;
+#endif
 
 }
 
