@@ -1,7 +1,7 @@
 /**
  * Main SMSD program
  */
-/* Copyright (c) 2009 - 2011 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
 /* Licensend under GNU GPL 2 */
 
 #include <gammu-smsd.h>
@@ -68,7 +68,6 @@ void smsd_resume(int signum)
 NORETURN void version(void)
 {
 	printf("Gammu-smsd version %s\n", GAMMU_VERSION);
-	printf("Built %s on %s using %s\n", __TIME__, __DATE__, GetCompiler());
 	printf("Compiled in features:\n");
 	printf("OS support:\n");
 #ifdef HAVE_SHM
@@ -116,9 +115,9 @@ NORETURN void version(void)
 	printf("  - %s\n", "ODBC");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2011 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2015 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
-	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
+	printf("License GPLv2: GNU GPL version 2 <https://spdx.org/licenses/GPL-2.0>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
@@ -353,7 +352,7 @@ void configure_daemon(SMSD_Parameters * params)
 #endif
 
 #ifdef HAVE_UID
-	if (params->gid != -1 || params->uid != -1) {
+	if (params->gid >= 0 || params->uid >= 0) {
 		if (!set_uid_gid(params)) {
 			fprintf(stderr, "changing uid/gid failed! (%s)\n", strerror(errno));
 			exit(1);
@@ -510,7 +509,7 @@ read_config:
 
 	/*
 	 * Wait while we should be suspended.
-	 * Later we fall back to reconfigure bellow.
+	 * Later we fall back to reconfigure below.
 	 */
 	while (standby) {
 		sleep(1);
