@@ -1,13 +1,14 @@
 /**
  * SMSD message monitor program
  */
-/* Copyright (c) 2009 - 2011 Michal Cihar <michal@cihar.com> */
+/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
 /* Licensend under GNU GPL 2 */
 
 #include <gammu-smsd.h>
 #include <assert.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <string.h>
 #ifndef WIN32
 #include <unistd.h>
 #endif
@@ -35,7 +36,6 @@ void smsd_interrupt(int signum)
 NORETURN void version(void)
 {
 	printf("Gammu-smsd-monitor version %s\n", GAMMU_VERSION);
-	printf("Built %s on %s using %s\n", __TIME__, __DATE__, GetCompiler());
 	printf("Compiled in features:\n");
 	printf("OS support:\n");
 #ifdef HAVE_SHM
@@ -63,9 +63,9 @@ NORETURN void version(void)
 	printf("  - %s\n", "ODBC");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2011 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2015 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
-	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
+	printf("License GPLv2: GNU GPL version 2 <https://spdx.org/licenses/GPL-2.0>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
@@ -109,7 +109,7 @@ NORETURN void wrong_params(void)
 	exit(1);
 }
 
-int process_commandline(int argc, char **argv, SMSD_Parameters * params)
+void process_commandline(int argc, char **argv, SMSD_Parameters * params)
 {
 	int opt;
 
@@ -133,7 +133,7 @@ int process_commandline(int argc, char **argv, SMSD_Parameters * params)
 	while ((opt = getopt(argc, argv, "+hvc:d:n:ClL")) != -1) {
 #else
 	/* Poor mans getopt replacement */
-	int i, optind = -1;
+	int i;
 
 #define optarg argv[++i]
 
@@ -171,19 +171,18 @@ int process_commandline(int argc, char **argv, SMSD_Parameters * params)
 				help();
 				exit(0);
 			default:
-#if defined(HAVE_GETOPT) || defined(HAVE_GETOPT_LONG)
 				wrong_params();
-#else
-				optind = 1;
-#endif
 				break;
 		}
-#if !defined(HAVE_GETOPT) && !defined(HAVE_GETOPT_LONG)
-		if (optind != -1) break;
-#endif
 	}
 
-	return optind;
+#if defined(HAVE_GETOPT) || defined(HAVE_GETOPT_LONG)
+	if (optind < argc) {
+		wrong_params();
+	}
+#endif
+
+	return;
 
 }
 
