@@ -1,4 +1,5 @@
 /* (c) 2002-2004 by Joergen Thomsen */
+/* Copyright (c) 2009 - 2015 Michal Cihar <michal@cihar.com> */
 
 #include <gammu.h>
 
@@ -8,6 +9,7 @@
 #include <time.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <sys/stat.h>
 
 #ifdef WIN32
 #include <io.h>
@@ -422,6 +424,8 @@ static GSM_Error SMSDFiles_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConf
 		SMSD_Log(DEBUG_NOTICE, Config, "error: SMS-count = 0");
 	}
 
+	Config->retries = 0;
+
 	return ERR_NONE;
 }
 
@@ -588,20 +592,144 @@ fail:
 
 static GSM_Error SMSDFiles_AddSentSMSInfo(GSM_MultiSMSMessage * sms UNUSED, GSM_SMSDConfig * Config, char *ID UNUSED, int Part, GSM_SMSDSendingError err, int TPMR)
 {
+	FILE *file;
+	ssize_t flen = 0, filesize;
+	unsigned char FullPath[400];
+	char *Buffer = NULL;
+	char *lineStart, *lineEnd;
+	/* MessageReference TPMR maximum is "255" */
+	char MessageReferenceBuffer[sizeof("MessageReference = \n") + 4];
+
 	if (err == SMSD_SEND_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Transmitted %s (%s: %i) to %s, message reference 0x%02x",
 			 Config->SMSID, (Part == sms->Number ? "total" : "part"), Part, DecodeUnicodeString(sms->SMS[0].Number), TPMR);
 	}
 
+	strcpy(FullPath, Config->outboxpath);
+	strcat(FullPath, Config->SMSID);
+
+	file = fopen(FullPath, "r");
+
+	if (file == NULL) {
+		return ERR_CANTOPENFILE;
+	}
+
+	fseek(file, 0, SEEK_END);
+	filesize = ftell(file);
+	if (filesize < 0) {
+		fclose(file);
+		return ERR_CANTOPENFILE;
+	}
+	fseek(file, 0, SEEK_SET);
+
+	Buffer = malloc(filesize + 200);
+	if (Buffer == NULL) {
+		fclose(file);
+		return ERR_MOREMEMORY;
+	}
+
+	flen = fread(Buffer, 1, filesize, file);
+	fclose(file);
+
+	if (flen != filesize) {
+		free(Buffer);
+		return ERR_CANTOPENFILE;
+	}
+	Buffer[flen] = '\0';
+
+	lineStart = Buffer;
+	lineEnd = strchr(lineStart, '\n');
+
+	while (lineEnd && lineStart - Buffer + 1 < flen) {
+		lineStart = lineEnd + 1;
+		lineEnd = strchr(lineStart, '\n');
+
+		if(!strncmp("MessageReference = ", lineStart, 19)) {
+			break;
+		}
+	}
+
+	/* Message reference not found */
+	if (lineEnd == NULL || strncmp("MessageReference = ", lineStart, 19) == 0) {
+		free(Buffer);
+		return ERR_NONE;
+	}
+
+	file = fopen(FullPath, "w");
+	if (file == NULL) {
+		free(Buffer);
+		return ERR_CANTOPENFILE;
+	}
+
+	chk_fwrite(Buffer, lineStart - Buffer, 1, file);
+
+	snprintf(MessageReferenceBuffer, sizeof(MessageReferenceBuffer),
+		 "MessageReference = %d\n", TPMR);
+
+
+	chk_fwrite(MessageReferenceBuffer, strlen(MessageReferenceBuffer), 1, file);
+
+	chk_fwrite(lineEnd + 1, (Buffer - lineEnd) + flen - 1, 1, file);
+
+	fclose(file);
+
+	free(Buffer);
+	return ERR_NONE;
+fail:
+	if (file) {
+		fclose(file);
+	}
+	if (Buffer) {
+		free(Buffer);
+	}
+	return ERR_WRITING_FILE;
+}
+
+GSM_Error SMSD_Check_Dir(GSM_SMSDConfig *Config, const char *path, const char *name)
+{
+#ifndef WIN32
+	struct stat s;
+
+	if (stat(path, &s) < 0) {
+		SMSD_Log(DEBUG_ERROR, Config, "Failed to stat \"%s\" (%s)", path, name);
+		return ERR_FILENOTEXIST;
+	}
+
+	if (!S_ISDIR(s.st_mode)) {
+		SMSD_Log(DEBUG_ERROR, Config, "The path \"%s\" (%s) is not a folder", path, name);
+		return ERR_FILENOTEXIST;
+	}
+#else
+	DWORD dwAttrib;
+
+	dwAttrib = GetFileAttributes(path);
+	if (dwAttrib == INVALID_FILE_ATTRIBUTES) {
+		SMSD_Log(DEBUG_ERROR, Config, "Failed to stat \"%s\" (%s)", path, name);
+		return ERR_FILENOTEXIST;
+	}
+
+	if ((dwAttrib & FILE_ATTRIBUTE_DIRECTORY) == 0) {
+		SMSD_Log(DEBUG_ERROR, Config, "The path \"%s\" (%s) is not a folder", path, name);
+		return ERR_FILENOTEXIST;
+	}
+#endif
 	return ERR_NONE;
 }
 
 GSM_Error SMSDFiles_ReadConfiguration(GSM_SMSDConfig *Config)
 {
 	static unsigned char	emptyPath[1] = "\0";
+	GSM_Error error;
 
 	Config->inboxpath=INI_GetValue(Config->smsdcfgfile, "smsd", "inboxpath", FALSE);
-	if (Config->inboxpath == NULL) Config->inboxpath = emptyPath;
+	if (Config->inboxpath == NULL) {
+		Config->inboxpath = emptyPath;
+	} else {
+		error = SMSD_Check_Dir(Config, Config->inboxpath, "inboxpath");
+		if (error != ERR_NONE) {
+			return error;
+		}
+	}
 
 	Config->inboxformat=INI_GetValue(Config->smsdcfgfile, "smsd", "inboxformat", FALSE);
 	if (Config->inboxformat == NULL ||
@@ -614,7 +742,14 @@ GSM_Error SMSDFiles_ReadConfiguration(GSM_SMSDConfig *Config)
 
 
 	Config->outboxpath=INI_GetValue(Config->smsdcfgfile, "smsd", "outboxpath", FALSE);
-	if (Config->outboxpath == NULL) Config->outboxpath = emptyPath;
+	if (Config->outboxpath == NULL) {
+		Config->outboxpath = emptyPath;
+	} else {
+		error = SMSD_Check_Dir(Config, Config->outboxpath, "outboxpath");
+		if (error != ERR_NONE) {
+			return error;
+		}
+	}
 
 	Config->transmitformat=INI_GetValue(Config->smsdcfgfile, "smsd", "transmitformat", FALSE);
 	if (Config->transmitformat == NULL || (strcasecmp(Config->transmitformat, "auto") != 0 && strcasecmp(Config->transmitformat, "unicode") != 0)) {
@@ -637,11 +772,25 @@ GSM_Error SMSDFiles_ReadConfiguration(GSM_SMSDConfig *Config)
 		Config->transmitformat);
 
 	Config->sentsmspath=INI_GetValue(Config->smsdcfgfile, "smsd", "sentsmspath", FALSE);
-	if (Config->sentsmspath == NULL) Config->sentsmspath = Config->outboxpath;
+	if (Config->sentsmspath == NULL) {
+		Config->sentsmspath = Config->outboxpath;
+	} else {
+		error = SMSD_Check_Dir(Config, Config->sentsmspath, "sentsmspath");
+		if (error != ERR_NONE) {
+			return error;
+		}
+	}
 	SMSD_Log(DEBUG_NOTICE, Config, "Sent SMS moved to \"%s\"",Config->sentsmspath);
 
 	Config->errorsmspath=INI_GetValue(Config->smsdcfgfile, "smsd", "errorsmspath", FALSE);
-	if (Config->errorsmspath == NULL) Config->errorsmspath = Config->sentsmspath;
+	if (Config->errorsmspath == NULL) {
+		Config->errorsmspath = Config->sentsmspath;
+	} else {
+		error = SMSD_Check_Dir(Config, Config->errorsmspath, "errorsmspath");
+		if (error != ERR_NONE) {
+			return error;
+		}
+	}
 	SMSD_Log(DEBUG_NOTICE, Config, "SMS with errors moved to \"%s\"",Config->errorsmspath);
 
 	return ERR_NONE;
@@ -656,6 +805,7 @@ GSM_SMSDService SMSDFiles = {
 	SMSDFiles_MoveSMS,
 	SMSDFiles_CreateOutboxSMS,
 	SMSDFiles_AddSentSMSInfo,
+	NOTIMPLEMENTED,		/* UpdateRetries        */
 	NOTIMPLEMENTED,		/* RefreshSendStatus    */
 	NOTIMPLEMENTED,		/* RefreshPhoneStatus   */
 	SMSDFiles_ReadConfiguration
