@@ -204,9 +204,9 @@ static const char *SMSDSQL_Now(GSM_SMSDConfig * Config)
 	}
 }
 
-static SQL_Error SMSDSQL_Reconnect(GSM_SMSDConfig * Config)
+static GSM_Error SMSDSQL_Reconnect(GSM_SMSDConfig * Config)
 {
-	SQL_Error error = SQL_TIMEOUT;
+	GSM_Error error = ERR_DB_TIMEOUT;
 	int attempts;
 	struct GSM_SMSDdbobj *db = Config->db;
 
@@ -216,27 +216,27 @@ static SQL_Error SMSDSQL_Reconnect(GSM_SMSDConfig * Config)
 		sleep(attempts * attempts);
 		db->Free(Config);
 		error = db->Connect(Config);
-		if (error == SQL_OK) {
-			return error;
+		if (error == ERR_NONE) {
+			return ERR_NONE;
 		}
 	}
 	return error;
 }
 
-static SQL_Error SMSDSQL_Query(GSM_SMSDConfig * Config, const char *query, SQL_result * res)
+static GSM_Error SMSDSQL_Query(GSM_SMSDConfig * Config, const char *query, SQL_result * res)
 {
-	SQL_Error error = SQL_TIMEOUT;
+	GSM_Error error = ERR_DB_TIMEOUT;
 	int attempts;
 	struct GSM_SMSDdbobj *db = Config->db;
 
 	for (attempts = 1; attempts <= Config->backend_retries; attempts++) {
 		SMSD_Log(DEBUG_SQL, Config, "Execute SQL: %s", query);
 		error = db->Query(Config, query, res);
-		if (error == SQL_OK) {
-			return error;
+		if (error == ERR_NONE) {
+			return ERR_NONE;
 		}
 
-		if (error != SQL_TIMEOUT){
+		if (error != ERR_DB_TIMEOUT){
 			SMSD_Log(DEBUG_INFO, Config, "SQL failure: %d", error);
 			return error;
 		}
@@ -244,7 +244,7 @@ static SQL_Error SMSDSQL_Query(GSM_SMSDConfig * Config, const char *query, SQL_r
 		SMSD_Log(DEBUG_INFO, Config, "SQL failed (timeout): %s", query);
 		/* We will try to reconnect */
 		error = SMSDSQL_Reconnect(Config);
-		if (error != SQL_OK) {
+		if (error != ERR_NONE) {
 			break;
 		}
 	}
@@ -278,7 +278,7 @@ void SMSDSQL_Time2String(GSM_SMSDConfig * Config, time_t timestamp, char *static
 	}
 }
 
-static SQL_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_query, GSM_SMSMessage *sms,
+static GSM_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_query, GSM_SMSMessage *sms,
 	const SQL_Var *params, SQL_result * res)
 {
 	char buff[65536], *ptr, c, static_buff[8192];
@@ -334,12 +334,12 @@ static SQL_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_que
 						break;
 					default:
 						SMSD_Log(DEBUG_ERROR, Config, "SQL: unknown type: %i (application bug) in query: `%s`", params[n].type, sql_query);
-						return SQL_BUG;
+						return ERR_BUG;
 						break;
 				}
 			} else {
 				SMSD_Log(DEBUG_ERROR, Config, "SQL: wrong number of parameter: %i (max %i) in query: `%s`", n+1, argc, sql_query);
-				return SQL_BUG;
+				return ERR_BUG;
 			}
 			q = end - 1;
 			continue;
@@ -445,12 +445,12 @@ static SQL_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_que
 							break;
 						default:
 							SMSD_Log(DEBUG_ERROR, Config, "SQL: uexpected char '%c' in query: %s", c, sql_query);
-							return SQL_BUG;
+							return ERR_BUG;
 
 					} /* end of switch */
 				} else {
 					SMSD_Log(DEBUG_ERROR, Config, "Syntax error in query.. uexpected char '%c' in query: %s", c, sql_query);
-					return SQL_BUG;
+					return ERR_BUG;
 				}
 				break;
 		} /* end of switch */
@@ -475,7 +475,7 @@ static GSM_Error SMSDSQL_CheckTable(GSM_SMSDConfig * Config, const char *table)
 {
 	SQL_result res;
 	char buffer[200];
-	SQL_Error error;
+	GSM_Error error;
 	struct GSM_SMSDdbobj *db = Config->db;
 	const char *escape_char;
 
@@ -483,10 +483,10 @@ static GSM_Error SMSDSQL_CheckTable(GSM_SMSDConfig * Config, const char *table)
 
 	sprintf(buffer, "SELECT %s %sID%s FROM %s %s", SMSDSQL_TopClause(Config, "1"), escape_char, escape_char, table, SMSDSQL_LimitClause(Config, "1"));
 	error = SMSDSQL_Query(Config, buffer, &res);
-	if (error != SQL_OK) {
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_ERROR, Config, "Table %s not found, disconnecting!", table);
 		db->Free(Config);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 	return ERR_NONE;
@@ -524,8 +524,9 @@ static GSM_Error SMSDSQL_Init(GSM_SMSDConfig * Config)
 
 	db = Config->db;
 
-	if (db->Connect(Config) != SQL_OK)
-		return ERR_UNKNOWN;
+	error = db->Connect(Config);
+	if (error != ERR_NONE)
+		return error;
 
 	error = SMSDSQL_CheckTable(Config, "outbox");
 	if (error != ERR_NONE)
@@ -543,9 +544,10 @@ static GSM_Error SMSDSQL_Init(GSM_SMSDConfig * Config)
 	escape_char = SMSDSQL_EscapeChar(Config);
 
 	sprintf(buffer, "SELECT %sVersion%s FROM gammu", escape_char, escape_char);
-	if (SMSDSQL_Query(Config, buffer, &res) != SQL_OK) {
+	error = SMSDSQL_Query(Config, buffer, &res);
+	if (error != ERR_NONE) {
 		db->Free(Config);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	if (db->NextRow(Config, &res) != 1) {
 		SMSD_Log(DEBUG_ERROR, Config, "Failed to seek to first row!");
@@ -555,9 +557,10 @@ static GSM_Error SMSDSQL_Init(GSM_SMSDConfig * Config)
 	}
 	version = db->GetNumber(Config, &res, 0);
 	db->FreeResult(Config, &res);
-	if (SMSD_CheckDBVersion(Config, version) != ERR_NONE) {
+	error = SMSD_CheckDBVersion(Config, version);
+	if (error != ERR_NONE) {
 		db->Free(Config);
-		return ERR_UNKNOWN;
+		return error;
 	}
 
 	SMSD_Log(DEBUG_INFO, Config, "Connected to Database %s: %s on %s", Config->driver, Config->database, Config->host);
@@ -568,12 +571,14 @@ static GSM_Error SMSDSQL_Init(GSM_SMSDConfig * Config)
 static GSM_Error SMSDSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 {
 	SQL_result res;
+	GSM_Error error;
 	struct GSM_SMSDdbobj *db = Config->db;
 	SQL_Var vars[3] = {{SQL_TYPE_STRING, {NULL}}, {SQL_TYPE_STRING, {NULL}}, {SQL_TYPE_NONE, {NULL}}};
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_PHONE], NULL, NULL, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_PHONE], NULL, NULL, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
@@ -581,9 +586,10 @@ static GSM_Error SMSDSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 	vars[0].v.s = Config->enable_send ? "yes" : "no";
 	vars[1].v.s = Config->enable_receive ? "yes" : "no";
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_INSERT_PHONE], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_INSERT_PHONE], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error inserting into database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
@@ -595,6 +601,7 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 {
 	SQL_result res, res2;
 	SQL_Var vars[3];
+	GSM_Error error;
 	struct GSM_SMSDdbobj *db = Config->db;
 	const char *q, *status;
 
@@ -618,9 +625,10 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 			EncodeUTF8(smstext, sms->SMS[i].Text);
 			SMSD_Log(DEBUG_INFO, Config, "Delivery report: %s to %s", smstext, destinationnumber);
 
-			if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_SELECT], &sms->SMS[i], NULL, &res) != SQL_OK) {
+			error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_SELECT], &sms->SMS[i], NULL, &res);
+			if (error != ERR_NONE) {
 				SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
-				return ERR_UNKNOWN;
+				return error;
 			}
 
 			found = FALSE;
@@ -680,9 +688,10 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 				vars[1].v.i = (long)db->GetNumber(Config, &res, 0); /* ID */
 				vars[2].type = SQL_TYPE_NONE;
 
-				if (SMSDSQL_NamedQuery(Config, q, &sms->SMS[i], vars, &res2) != SQL_OK) {
+				error = SMSDSQL_NamedQuery(Config, q, &sms->SMS[i], vars, &res2);
+				if (error != ERR_NONE) {
 					SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-					return ERR_UNKNOWN;
+					return error;
 				}
 				db->FreeResult(Config, &res2);
 			} else {
@@ -695,9 +704,10 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 		if (sms->SMS[i].PDU != SMS_Deliver)
 			continue;
 
-		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_INSERT], &sms->SMS[i], NULL, &res) != SQL_OK) {
+		error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_INSERT], &sms->SMS[i], NULL, &res);
+		if (error != ERR_NONE) {
 			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-			return ERR_UNKNOWN;
+			return error;
 		}
 
 		new_id = db->SeqID(Config, "inbox_ID_seq");
@@ -721,9 +731,10 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 			locations_pos += sprintf((*Locations) + locations_pos, "%lu ", (long)new_id);
 		}
 
-		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_RECEIVED], &sms->SMS[i], NULL, &res2) != SQL_OK) {
+		error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_RECEIVED], &sms->SMS[i], NULL, &res2);
+		if (error != ERR_NONE) {
 			SMSD_Log(DEBUG_INFO, Config, "Error updating number of received messages (%s)", __FUNCTION__);
-			return ERR_UNKNOWN;
+			return error;
 		}
 		db->FreeResult(Config, &res2);
 
@@ -736,13 +747,15 @@ static GSM_Error SMSDSQL_RefreshSendStatus(GSM_SMSDConfig * Config, char *ID)
 {
 	SQL_result res;
 	struct GSM_SMSDdbobj *db = Config->db;
+	GSM_Error error;
 	SQL_Var vars[2] = {
 		{SQL_TYPE_STRING, {ID}},
 		{SQL_TYPE_NONE, {NULL}}};
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_SEND_STATUS], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_SEND_STATUS], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 
 	if (db->AffectedRows(Config, &res) == 0) {
@@ -759,6 +772,7 @@ static GSM_Error SMSDSQL_RefreshSendStatus(GSM_SMSDConfig * Config, char *ID)
 static GSM_Error SMSDSQL_UpdateRetries(GSM_SMSDConfig * Config, char *ID)
 {
 	SQL_result res;
+	GSM_Error error;
 	struct GSM_SMSDdbobj *db = Config->db;
 	SQL_Var vars[3] = {
 		{SQL_TYPE_STRING, {ID}},
@@ -766,9 +780,10 @@ static GSM_Error SMSDSQL_UpdateRetries(GSM_SMSDConfig * Config, char *ID)
 		{SQL_TYPE_NONE, {NULL}}};
 	vars[1].v.i = Config->retries;
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_RETRIES], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_RETRIES], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 
 	if (db->AffectedRows(Config, &res) == 0) {
@@ -798,15 +813,17 @@ static GSM_Error SMSDSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 	const char *q;
 	size_t udh_len;
 	SQL_Var vars[3];
+	GSM_Error error;
 
 	vars[0].type = SQL_TYPE_INT;
 	vars[0].v.i = 1;
 	vars[1].type = SQL_TYPE_NONE;
 
 	while (TRUE) {
-		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_SMS_ID], NULL, vars, &res) != SQL_OK) {
+		error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_SMS_ID], NULL, vars, &res);
+		if (error != ERR_NONE) {
 			SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
-			return ERR_UNKNOWN;
+			return error;
 		}
 
 		if (db->NextRow(Config, &res) != 1) {
@@ -848,9 +865,10 @@ static GSM_Error SMSDSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 		} else {
 			q = Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_MULTIPART];
 		}
-		if (SMSDSQL_NamedQuery(Config, q, NULL, vars, &res) != SQL_OK) {
+		error = SMSDSQL_NamedQuery(Config, q, NULL, vars, &res);
+		if (error != ERR_NONE) {
 			SMSD_Log(DEBUG_ERROR, Config, "Error reading from database (%s)", __FUNCTION__);
-			return ERR_UNKNOWN;
+			return error;
 		}
 
 		if (db->NextRow(Config, &res) != 1) {
@@ -958,20 +976,23 @@ static GSM_Error SMSDSQL_MoveSMS(GSM_MultiSMSMessage * sms UNUSED, GSM_SMSDConfi
 	SQL_result res;
 	SQL_Var vars[2];
 	struct GSM_SMSDdbobj *db = Config->db;
+	GSM_Error error;
 
 	vars[0].type = SQL_TYPE_STRING;
 	vars[0].v.s = ID;
 	vars[1].type = SQL_TYPE_NONE;
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX_MULTIPART], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX_MULTIPART], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
@@ -988,6 +1009,7 @@ static GSM_Error SMSDSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConf
 	SQL_Var vars[6];
 	struct GSM_SMSDdbobj *db = Config->db;
 	const char *report, *multipart, *q;
+	GSM_Error error;
 
 	sprintf(creator, "Gammu %s",GAMMU_VERSION); /* %1 */
 	multipart = (sms->Number == 1) ? "FALSE" : "TRUE"; /* %3 */
@@ -1012,9 +1034,10 @@ static GSM_Error SMSDSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConf
 		vars[4].v.i = ID;
 		vars[5].type = SQL_TYPE_NONE;
 
-		if (SMSDSQL_NamedQuery(Config, q, &sms->SMS[i], vars, &res) != SQL_OK) {
+		error = SMSDSQL_NamedQuery(Config, q, &sms->SMS[i], vars, &res);
+		if (error != ERR_NONE) {
 			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-			return ERR_UNKNOWN;
+			return error;
 		}
 		if (i == 0) {
 			ID = db->SeqID(Config, "outbox_ID_seq");
@@ -1035,6 +1058,7 @@ static GSM_Error SMSDSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms, GSM_SMSDConfi
 {
 	SQL_result res;
 	struct GSM_SMSDdbobj *db = Config->db;
+	GSM_Error error;
 
 	const char *message_state;
 	SQL_Var vars[6];
@@ -1077,15 +1101,17 @@ static GSM_Error SMSDSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms, GSM_SMSDConfi
 	vars[4].v.s = Config->DT;
 	vars[5].type = SQL_TYPE_NONE;
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_ADD_SENT_INFO], &sms->SMS[Part - 1], vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_ADD_SENT_INFO], &sms->SMS[Part - 1], vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_SENT], &sms->SMS[Part - 1], NULL, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_SENT], &sms->SMS[Part - 1], NULL, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
@@ -1100,12 +1126,15 @@ static GSM_Error SMSDSQL_RefreshPhoneStatus(GSM_SMSDConfig * Config)
 		{SQL_TYPE_INT, {NULL}},
 		{SQL_TYPE_NONE, {NULL}}};
 	struct GSM_SMSDdbobj *db = Config->db;
+	GSM_Error error;
+
 	vars[0].v.i = Config->Status->Charge.BatteryPercent;
 	vars[1].v.i = Config->Status->Network.SignalPercent;
 
-	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_PHONE_STATUS], NULL, vars, &res) != SQL_OK) {
+	error = SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_PHONE_STATUS], NULL, vars, &res);
+	if (error != ERR_NONE) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+		return error;
 	}
 	db->FreeResult(Config, &res);
 
